==> docfbe_2_2_33_59.zip: docfbe_2_2_33_59/source/TCFbERecommendationOutputFormatter.h <==
/*
    TCFbERecommendationOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERecommendationOutputFormatterH
#define TCFbERecommendationOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbEOutputFormatter.h"
#include "TCFbECommandLineParser.h"
#include "TCFbEOutputCash.h"
#include "TCFbERecommendedItem.h"
//---------------------------------------------------------------------------
class TCFbERecommendationOutputFormatter : public TCFbEOutputFormatter
{
public:
    virtual __fastcall TCFbERecommendationOutputFormatter(TCFbECommandLineParser* Parser, TCFbEOutputCash* OutputCash, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbERecommendationOutputFormatter();    // fXgN^

protected:
    virtual void __fastcall OutputHeader(void);    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex);    // {fB this->FOutputStringList ɒǉD

    virtual void __fastcall GetSortedResultList(int RowIndex, TList* SortedResultList);    // RowIndex Ԗڂ̍šʂ\[gCSortedResultList ɓĕԂ

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_42_72.zip: docfbe_2_3_42_72/source/TCFbERecommendationOutputFormatter.h <==
/*
    TCFbERecommendationOutputFormatter.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbERecommendationOutputFormatterH
#define TCFbERecommendationOutputFormatterH
//---------------------------------------------------------------------------
#include <stdio.h>
#include <system.hpp>
#include <SysUtils.hpp>

#include "TCFbEOutputFormatter.h"
#include "TCFbEDocfbeCommandLineParser.h"
#include "TCFbEOutputCache.h"
#include "TCFbERecommendedItem.h"
//---------------------------------------------------------------------------
class TCFbERecommendationOutputFormatter : public TCFbEOutputFormatter
{
public:
    virtual __fastcall TCFbERecommendationOutputFormatter(TCFbEDocfbeCommandLineParser* Parser, TCFbEOutputCache* OutputCache, bool IsVerbose=false);    // RXgN^
    __fastcall ~TCFbERecommendationOutputFormatter();    // fXgN^

protected:
    virtual void __fastcall OutputHeader(void);    // wb_ this->FOutputStringList ɒǉDwb_KvłȂꍇ͂ return D
    virtual void __fastcall OutputBody(int TargetRowIndex);    // {fB this->FOutputStringList ɒǉD

    virtual void __fastcall GetSortedResultList(int RowIndex, TList* SortedResultList);    // RowIndex Ԗڂ̍šʂ\[gCSortedResultList ɓĕԂ

private:

};
//---------------------------------------------------------------------------
#endif
